==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/inputs/GalleryImageVersionStorageProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.inputs

import com.pulumi.azurenative.compute.inputs.GalleryImageVersionStorageProfileArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * This is the storage profile of a Gallery Image Version.
 * @property dataDiskImages A list of data disk images.
 * @property osDiskImage This is the OS disk image.
 * @property source The source of the gallery artifact version.
 */
public data class GalleryImageVersionStorageProfileArgs(
    public val dataDiskImages: Output<List<GalleryDataDiskImageArgs>>? = null,
    public val osDiskImage: Output<GalleryOSDiskImageArgs>? = null,
    public val source: Output<GalleryArtifactVersionFullSourceArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.compute.inputs.GalleryImageVersionStorageProfileArgs> {
    override fun toJava(): com.pulumi.azurenative.compute.inputs.GalleryImageVersionStorageProfileArgs =
        com.pulumi.azurenative.compute.inputs.GalleryImageVersionStorageProfileArgs.builder()
            .dataDiskImages(
                dataDiskImages?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .osDiskImage(osDiskImage?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .source(source?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [GalleryImageVersionStorageProfileArgs].
 */
@PulumiTagMarker
public class GalleryImageVersionStorageProfileArgsBuilder internal constructor() {
    private var dataDiskImages: Output<List<GalleryDataDiskImageArgs>>? = null

    private var osDiskImage: Output<GalleryOSDiskImageArgs>? = null

    private var source: Output<GalleryArtifactVersionFullSourceArgs>? = null

    /**
     * @param value A list of data disk images.
     */
    @JvmName("shecssqojrivkhsb")
    public suspend fun dataDiskImages(`value`: Output<List<GalleryDataDiskImageArgs>>) {
        this.dataDiskImages = value
    }

    @JvmName("xgvjaldkqxkaiwwe")
    public suspend fun dataDiskImages(vararg values: Output<GalleryDataDiskImageArgs>) {
        this.dataDiskImages = Output.all(values.asList())
    }

    /**
     * @param values A list of data disk images.
     */
    @JvmName("hqvcvmgpbumlaybi")
    public suspend fun dataDiskImages(values: List<Output<GalleryDataDiskImageArgs>>) {
        this.dataDiskImages = Output.all(values)
    }

    /**
     * @param value This is the OS disk image.
     */
    @JvmName("lvsgjglfmukanwnj")
    public suspend fun osDiskImage(`value`: Output<GalleryOSDiskImageArgs>) {
        this.osDiskImage = value
    }

    /**
     * @param value The source of the gallery artifact version.
     */
    @JvmName("xfhqxywacdcfmjhn")
    public suspend fun source(`value`: Output<GalleryArtifactVersionFullSourceArgs>) {
        this.source = value
    }

    /**
     * @param value A list of data disk images.
     */
    @JvmName("wowfjggeqiyolmhl")
    public suspend fun dataDiskImages(`value`: List<GalleryDataDiskImageArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dataDiskImages = mapped
    }

    /**
     * @param argument A list of data disk images.
     */
    @JvmName("vlggyjlonmtvldmg")
    public suspend
    fun dataDiskImages(argument: List<suspend GalleryDataDiskImageArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            GalleryDataDiskImageArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.dataDiskImages = mapped
    }

    /**
     * @param argument A list of data disk images.
     */
    @JvmName("qmdnbfjhvvhypyum")
    public suspend fun dataDiskImages(
        vararg
        argument: suspend GalleryDataDiskImageArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            GalleryDataDiskImageArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.dataDiskImages = mapped
    }

    /**
     * @param argument A list of data disk images.
     */
    @JvmName("wlslpdxpxuefursg")
    public suspend fun dataDiskImages(argument: suspend GalleryDataDiskImageArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(GalleryDataDiskImageArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.dataDiskImages = mapped
    }

    /**
     * @param values A list of data disk images.
     */
    @JvmName("sbmyetdgnjogolot")
    public suspend fun dataDiskImages(vararg values: GalleryDataDiskImageArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dataDiskImages = mapped
    }

    /**
     * @param value This is the OS disk image.
     */
    @JvmName("tmkkpybnqycxturo")
    public suspend fun osDiskImage(`value`: GalleryOSDiskImageArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.osDiskImage = mapped
    }

    /**
     * @param argument This is the OS disk image.
     */
    @JvmName("trjwjpcnqoluhuok")
    public suspend fun osDiskImage(argument: suspend GalleryOSDiskImageArgsBuilder.() -> Unit) {
        val toBeMapped = GalleryOSDiskImageArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.osDiskImage = mapped
    }

    /**
     * @param value The source of the gallery artifact version.
     */
    @JvmName("ygixpkmrfaeoerts")
    public suspend fun source(`value`: GalleryArtifactVersionFullSourceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.source = mapped
    }

    /**
     * @param argument The source of the gallery artifact version.
     */
    @JvmName("rnbqsilxjtihacuu")
    public suspend
    fun source(argument: suspend GalleryArtifactVersionFullSourceArgsBuilder.() -> Unit) {
        val toBeMapped = GalleryArtifactVersionFullSourceArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.source = mapped
    }

    internal fun build(): GalleryImageVersionStorageProfileArgs =
        GalleryImageVersionStorageProfileArgs(
            dataDiskImages = dataDiskImages,
            osDiskImage = osDiskImage,
            source = source,
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/inputs/GalleryImageVersionStorageProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.inputs

import com.pulumi.azurenative.compute.inputs.GalleryImageVersionStorageProfileArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * This is the storage profile of a Gallery Image Version.
 * @property dataDiskImages A list of data disk images.
 * @property osDiskImage This is the OS disk image.
 * @property source The source of the gallery artifact version.
 */
public data class GalleryImageVersionStorageProfileArgs(
    public val dataDiskImages: Output<List<GalleryDataDiskImageArgs>>? = null,
    public val osDiskImage: Output<GalleryOSDiskImageArgs>? = null,
    public val source: Output<GalleryArtifactVersionFullSourceArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.compute.inputs.GalleryImageVersionStorageProfileArgs> {
    override fun toJava(): com.pulumi.azurenative.compute.inputs.GalleryImageVersionStorageProfileArgs =
        com.pulumi.azurenative.compute.inputs.GalleryImageVersionStorageProfileArgs.builder()
            .dataDiskImages(
                dataDiskImages?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .osDiskImage(osDiskImage?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .source(source?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [GalleryImageVersionStorageProfileArgs].
 */
@PulumiTagMarker
public class GalleryImageVersionStorageProfileArgsBuilder internal constructor() {
    private var dataDiskImages: Output<List<GalleryDataDiskImageArgs>>? = null

    private var osDiskImage: Output<GalleryOSDiskImageArgs>? = null

    private var source: Output<GalleryArtifactVersionFullSourceArgs>? = null

    /**
     * @param value A list of data disk images.
     */
    @JvmName("rwvktcdeqygrpsir")
    public suspend fun dataDiskImages(`value`: Output<List<GalleryDataDiskImageArgs>>) {
        this.dataDiskImages = value
    }

    @JvmName("ixeqhcaygdvsudvh")
    public suspend fun dataDiskImages(vararg values: Output<GalleryDataDiskImageArgs>) {
        this.dataDiskImages = Output.all(values.asList())
    }

    /**
     * @param values A list of data disk images.
     */
    @JvmName("qretablerrmvsdgo")
    public suspend fun dataDiskImages(values: List<Output<GalleryDataDiskImageArgs>>) {
        this.dataDiskImages = Output.all(values)
    }

    /**
     * @param value This is the OS disk image.
     */
    @JvmName("djpvjejashuewthm")
    public suspend fun osDiskImage(`value`: Output<GalleryOSDiskImageArgs>) {
        this.osDiskImage = value
    }

    /**
     * @param value The source of the gallery artifact version.
     */
    @JvmName("hvgxlqvvwasybmxu")
    public suspend fun source(`value`: Output<GalleryArtifactVersionFullSourceArgs>) {
        this.source = value
    }

    /**
     * @param value A list of data disk images.
     */
    @JvmName("jgvedvxidfhrobja")
    public suspend fun dataDiskImages(`value`: List<GalleryDataDiskImageArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dataDiskImages = mapped
    }

    /**
     * @param argument A list of data disk images.
     */
    @JvmName("ehraetsgfxtkofma")
    public suspend
    fun dataDiskImages(argument: List<suspend GalleryDataDiskImageArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            GalleryDataDiskImageArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.dataDiskImages = mapped
    }

    /**
     * @param argument A list of data disk images.
     */
    @JvmName("ixentavkrpvxtqxs")
    public suspend fun dataDiskImages(
        vararg
        argument: suspend GalleryDataDiskImageArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            GalleryDataDiskImageArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.dataDiskImages = mapped
    }

    /**
     * @param argument A list of data disk images.
     */
    @JvmName("ahxmiwssjfkhpebu")
    public suspend fun dataDiskImages(argument: suspend GalleryDataDiskImageArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(GalleryDataDiskImageArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.dataDiskImages = mapped
    }

    /**
     * @param values A list of data disk images.
     */
    @JvmName("sjqobjicqrchumxu")
    public suspend fun dataDiskImages(vararg values: GalleryDataDiskImageArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dataDiskImages = mapped
    }

    /**
     * @param value This is the OS disk image.
     */
    @JvmName("gxelpfyvpgonygaq")
    public suspend fun osDiskImage(`value`: GalleryOSDiskImageArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.osDiskImage = mapped
    }

    /**
     * @param argument This is the OS disk image.
     */
    @JvmName("acxvajoxgsmxlvac")
    public suspend fun osDiskImage(argument: suspend GalleryOSDiskImageArgsBuilder.() -> Unit) {
        val toBeMapped = GalleryOSDiskImageArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.osDiskImage = mapped
    }

    /**
     * @param value The source of the gallery artifact version.
     */
    @JvmName("qqpvswujwscvlmoc")
    public suspend fun source(`value`: GalleryArtifactVersionFullSourceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.source = mapped
    }

    /**
     * @param argument The source of the gallery artifact version.
     */
    @JvmName("qcultsbdumqyyqao")
    public suspend
    fun source(argument: suspend GalleryArtifactVersionFullSourceArgsBuilder.() -> Unit) {
        val toBeMapped = GalleryArtifactVersionFullSourceArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.source = mapped
    }

    internal fun build(): GalleryImageVersionStorageProfileArgs =
        GalleryImageVersionStorageProfileArgs(
            dataDiskImages = dataDiskImages,
            osDiskImage = osDiskImage,
            source = source,
        )
}
